"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.clear = clear;

var _utils = require("./utils");

var _type = require("./type");

function clear(element) {
  var _el$selectionStart, _el$selectionEnd;

  if (!(0, _utils.isInstanceOfElement)(element, 'HTMLInputElement') && !(0, _utils.isInstanceOfElement)(element, 'HTMLTextAreaElement')) {
    // TODO: support contenteditable
    throw new Error('clear currently only supports input and textarea elements.');
  }

  const el = element;

  if ((0, _utils.isDisabled)(el)) {
    return;
  } // TODO: track the selection range ourselves so we don't have to do this input "type" trickery
  // just like cypress does: https://github.com/cypress-io/cypress/blob/8d7f1a0bedc3c45a2ebf1ff50324b34129fdc683/packages/driver/src/dom/selection.ts#L16-L37


  const elementType = el.type;

  if (elementType !== 'textarea') {
    // setSelectionRange is not supported on certain types of inputs, e.g. "number" or "email"
    ;
    element.type = 'text';
  }

  (0, _type.type)(element, '{selectall}{del}', {
    delay: 0,
    initialSelectionStart: (_el$selectionStart = el.selectionStart) != null ? _el$selectionStart :
    /* istanbul ignore next */
    undefined,
    initialSelectionEnd: (_el$selectionEnd = el.selectionEnd) != null ? _el$selectionEnd :
    /* istanbul ignore next */
    undefined
  });

  if (elementType !== 'textarea') {
    ;
    el.type = elementType;
  }
}