"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fireInputEventIfNeeded = fireInputEventIfNeeded;

var _dom = require("@testing-library/dom");

var _utils = require("../../utils");

var _setSelectionRange = require("./setSelectionRange");

function fireInputEventIfNeeded({
  currentElement,
  newValue,
  newSelectionStart,
  eventOverrides
}) {
  const el = currentElement();
  const prevValue = (0, _utils.getValue)(el);

  if (el && !isReadonly(el) && !(0, _utils.isClickableInput)(el) && newValue !== prevValue) {
    if ((0, _utils.isContentEditable)(el)) {
      _dom.fireEvent.input(el, {
        target: {
          textContent: newValue
        },
        ...eventOverrides
      });
    } else {
      _dom.fireEvent.input(el, {
        target: {
          value: newValue
        },
        ...eventOverrides
      });
    }

    (0, _setSelectionRange.setSelectionRange)({
      currentElement,
      newValue,
      newSelectionStart
    });
  }

  return {
    prevValue
  };
}

function isReadonly(element) {
  if (!(0, _utils.isInstanceOfElement)(element, 'HTMLInputElement') && !(0, _utils.isInstanceOfElement)(element, 'HTMLTextAreaElement')) {
    return false;
  }

  return element.readOnly;
}